from direct.showbase.ShowBase import ShowBase, TextureStage, TexGenAttrib
from direct.filter.CommonFilters import CommonFilters
from direct.showbase.InputStateGlobal import inputState
from panda3d.core import (loadPrcFileData, 
                         WindowProperties, 
                         AmbientLight, 
                         DirectionalLight,
                         LightRampAttrib, 
                         Vec3)
from panda3d.bullet import (BulletDebugNode, 
                            BulletWorld)
import sys
loadPrcFileData("", "show-frame-rate-meter #t")
loadPrcFileData("", "sync-video #t")
loadPrcFileData("", "frame-rate-meter-milliseconds true")
loadPrcFileData("", "show-scene-graph-analyzer-meter true")

from fix_gltf_bam import render_stage_convert


class MyApp(ShowBase):

    def __init__(self):
        ShowBase.__init__(self)
        props = WindowProperties()
        props.setTitle("bad_lighting")
        base.win.requestProperties(props)
        self._set_up_environment_lighting()
        self._set_up_toon_shading()
        self._setup_level()
        self.accept("q", self.exit)
        self._debug_bullet()

    def exit(self):
        sys.exit()

    def _set_up_toon_shading(self):
        self.separation = 1.2  # Pixels
        self.filters = CommonFilters(self.win, self.cam)
        filterok = self.filters.setCartoonInk(separation=self.separation)
        if (filterok == False):
            print(
                "Toon Shader: Video card not powerful enough to do image postprocessing")
            return

    def _set_up_environment_lighting(self):
        base.render.setShaderAuto()
        base.render.setAttrib(LightRampAttrib.makeSingleThreshold(0.2,0.6))
        self.sun = DirectionalLight("sun")
        self.sun.setColor((0.8, 0.8, 0.8, 1))
        base.sunnp = self.render.attachNewNode( self.sun)
        base.sunnp.setZ(base.sunnp, 50)
        base.sunnp.setY(base.sunnp, -30)
        base.sunnp.setP(base.sunnp, -90)
        base.sunnp.node().setShadowCaster(True, 512, 512)
        base.sunnp.node().getLens().setFilmSize(2,2)
        base.sunnp.node().showFrustum()
        base.render.setLight(base.sunnp)
        self.ambient_light = AmbientLight('alight')
        self.ambient_light.setColor((0.9, 0.9, 0.9, 1))
        self.alnp = self.render.attachNewNode(self.ambient_light)
        self.render.setLight(self.alnp)

    def _debug_bullet(self):
        debugNode = BulletDebugNode('Debug')
        debugNode.showWireframe(True)
        debugNode.showConstraints(True)
        debugNode.showBoundingBoxes(True)
        debugNode.showNormals(True)
        debugNP = render.attachNewNode(debugNode)
        debugNP.show()
        base.bullet_world.setDebugNode(debugNP.node())

    def _setup_level(self):
        base.bullet_world_node_path = self.render.attachNewNode('World')
        base.bullet_world = BulletWorld()
        base.bullet_world.setGravity(Vec3(0, 0, 0)) # (0,0,-14)
        playground = loader.loadModel("playground3.bam")

        render_stage_convert(playground, use_modulate = True, use_normal = False, use_selector = False, use_emission = False)

        for node_path in playground.find_all_matches('**/+BulletRigidBodyNode'):
            base.bullet_world.attachRigidBody(node_path.node())
        playground.reparentTo(base.bullet_world_node_path)
        self.taskMgr.add(self.update, sort=-2)

    def update(self, task):
        dt = globalClock.getDt()
        base.bullet_world.doPhysics(dt, 5, 1.0/180.0)
        return task.cont

app = MyApp()
app.run()